import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataAzureadServicePrincipalsConfig extends cdktf.TerraformMetaArguments {
    /**
     * The application IDs (client IDs) of the applications associated with the service principals.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/service_principals.html#application_ids DataAzureadServicePrincipals#application_ids}
     *
     * @stability stable
     */
    readonly applicationIds?: string[];
    /**
     * The display names of the applications associated with the service principals.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/service_principals.html#display_names DataAzureadServicePrincipals#display_names}
     *
     * @stability stable
     */
    readonly displayNames?: string[];
    /**
     * Ignore missing service principals and return the service principals that were found.
     *
     * The data source will still fail if no service principals are found
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/service_principals.html#ignore_missing DataAzureadServicePrincipals#ignore_missing}
     *
     * @stability stable
     */
    readonly ignoreMissing?: boolean | cdktf.IResolvable;
    /**
     * The object IDs of the service principals.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/service_principals.html#object_ids DataAzureadServicePrincipals#object_ids}
     *
     * @stability stable
     */
    readonly objectIds?: string[];
    /**
     * Fetch all service principals with no filter and return all that were found.
     *
     * The data source will still fail if no service principals are found.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/service_principals.html#return_all DataAzureadServicePrincipals#return_all}
     *
     * @stability stable
     */
    readonly returnAll?: boolean | cdktf.IResolvable;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/service_principals.html#timeouts DataAzureadServicePrincipals#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DataAzureadServicePrincipalsTimeouts;
}
/**
 * @stability stable
 */
export declare class DataAzureadServicePrincipalsServicePrincipals extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get accountEnabled(): any;
    /**
     * @stability stable
     */
    get appRoleAssignmentRequired(): any;
    /**
     * @stability stable
     */
    get applicationId(): string;
    /**
     * @stability stable
     */
    get applicationTenantId(): string;
    /**
     * @stability stable
     */
    get displayName(): string;
    /**
     * @stability stable
     */
    get preferredSingleSignOnMode(): string;
    /**
     * @stability stable
     */
    get samlMetadataUrl(): string;
    /**
     * @stability stable
     */
    get servicePrincipalNames(): string[];
    /**
     * @stability stable
     */
    get signInAudience(): string;
    /**
     * @stability stable
     */
    get tags(): string[];
    /**
     * @stability stable
     */
    get type(): string;
}
/**
 * @stability stable
 */
export interface DataAzureadServicePrincipalsTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/service_principals.html#read DataAzureadServicePrincipals#read}.
     *
     * @stability stable
     */
    readonly read?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azuread/d/service_principals.html azuread_service_principals}.
 *
 * @stability stable
 */
export declare class DataAzureadServicePrincipals extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azuread/d/service_principals.html azuread_service_principals} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: DataAzureadServicePrincipalsConfig);
    private _applicationIds?;
    /**
     * @stability stable
     */
    get applicationIds(): string[];
    /**
     * @stability stable
     */
    set applicationIds(value: string[]);
    /**
     * @stability stable
     */
    resetApplicationIds(): void;
    /**
     * @stability stable
     */
    get applicationIdsInput(): string[] | undefined;
    private _displayNames?;
    /**
     * @stability stable
     */
    get displayNames(): string[];
    /**
     * @stability stable
     */
    set displayNames(value: string[]);
    /**
     * @stability stable
     */
    resetDisplayNames(): void;
    /**
     * @stability stable
     */
    get displayNamesInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _ignoreMissing?;
    /**
     * @stability stable
     */
    get ignoreMissing(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set ignoreMissing(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIgnoreMissing(): void;
    /**
     * @stability stable
     */
    get ignoreMissingInput(): boolean | cdktf.IResolvable | undefined;
    private _objectIds?;
    /**
     * @stability stable
     */
    get objectIds(): string[];
    /**
     * @stability stable
     */
    set objectIds(value: string[]);
    /**
     * @stability stable
     */
    resetObjectIds(): void;
    /**
     * @stability stable
     */
    get objectIdsInput(): string[] | undefined;
    private _returnAll?;
    /**
     * @stability stable
     */
    get returnAll(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set returnAll(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReturnAll(): void;
    /**
     * @stability stable
     */
    get returnAllInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    servicePrincipals(index: string): DataAzureadServicePrincipalsServicePrincipals;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): DataAzureadServicePrincipalsTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: DataAzureadServicePrincipalsTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DataAzureadServicePrincipalsTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
